@@ -4,11 +4,13 @@ import typing
 import scipy.io
 import numpy as np
 
-# from d3m_metadata.container.numpy import ndarray
-# from d3m_metadata import hyperparams, params
-from d3m_metadata import container, hyperparams, metadata as metadata_module, params, utils
-from primitive_interfaces.supervised_learning import SupervisedLearnerPrimitiveBase
-from primitive_interfaces.base import CallResult
+from d3m import container
+from d3m.metadata import base as metadata_base
+from d3m.metadata import hyperparams
+from d3m.metadata import params
+from d3m.primitive_interfaces.supervised_learning import SupervisedLearnerPrimitiveBase
+from d3m.primitive_interfaces import base
+from d3m.primitive_interfaces.base import CallResult
 # from . import __version__
 
 
@@ -40,9 +42,9 @@ class Hyperparams(hyperparams.Hyperparams):
 
 class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hyperparams]):
 
-    metadata = metadata_module.PrimitiveMetadata({
+    metadata = metadata_base.PrimitiveMetadata({
         'id': '69845479-0b61-3578-b382-972cd0e61d69',
-        'version': '2.1.2',
+        'version': '2.1.3',
         'name': 'IPCMB feature selector',
         'keywords': ['rpi primitives'],
         'source': {
@@ -50,19 +52,21 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
         },
         'installation':[
             {
-                'type': 'PIP',
+                'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.0.5'
+                'version': '2.0.7'
             },
             {
-                'type': 'PIP',
+                'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.1.7'
+                'version': '2.1.8'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.IPCMBplus_Selector',
-        'algorithm_types': ['MINIMUM_REDUNDANCY_FEATURE_SELECTION'],
-        'primitive_family': 'FEATURE_SELECTION',
+        'algorithm_types': [
+            metadata_base.PrimitiveAlgorithmType.MINIMUM_REDUNDANCY_FEATURE_SELECTION
+        ],
+        'primitive_family': metadata_base.PrimitiveFamily.FEATURE_SELECTION,
         'preconditions': [
             "NO_CATEGORICAL_VALUES",
             "NO_MISSING_VALUES"
@@ -70,7 +74,7 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
     })
 
 
-    def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: typing.Dict[str, str] = None) -> None:
+    def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: typing.Union[typing.Dict[str, base.DockerContainer]] = None) -> None:
         super().__init__(hyperparams=hyperparams, random_seed=random_seed, docker_containers=docker_containers)
         self._index = None
         self._training_inputs = None
@@ -91,10 +95,10 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
             raise ValueError('Missing training data, or missing values exist.')
 
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
+        dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))        
 
         a = rpi_feature_selection_toolbox.initialize()
-        index = np.reshape(np.array(a.IPCMBplus()), [-1, ])
-
+        index = np.reshape(np.array(a.IPCMBplus(dir_path)), [-1, ])
         self._index = (index - 1).astype(int)
         self._fitted = True
 
@@ -121,9 +125,9 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
 
 class JMIplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hyperparams]):
 
-    metadata = metadata_module.PrimitiveMetadata({
+    metadata = metadata_base.PrimitiveMetadata({
         'id': '58a8fe68-74eb-3e21-a823-bfa708010759',
-        'version': '2.1.2',
+        'version': '2.1.3',
         'name': 'JMIplus feature selector',
         'keywords': ['rpi primitives'],
         'source': {
@@ -131,14 +135,14 @@ class JMIplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
         },
         'installation':[
             {
-                'type': 'PIP',
+                'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.0.5'
+                'version': '2.0.7'
             },
             {
-                'type': 'PIP',
+                'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.1.7'
+	            'version': '2.1.8'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.JMIplus_Selector',
@@ -151,7 +155,7 @@ class JMIplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
     })
 
 
-    def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: typing.Dict[str, str] = None) -> None:
+    def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: typing.Union[typing.Dict[str, base.DockerContainer]] = None) -> None:
         super().__init__(hyperparams=hyperparams, random_seed=random_seed, docker_containers=docker_containers)
         self._index = None
         self._training_inputs = None
@@ -172,9 +176,10 @@ class JMIplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
             raise ValueError('Missing training data, or missing values exist.')
 
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
+        dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
 
         a = rpi_feature_selection_toolbox.initialize()
-        index = np.reshape(np.array(a.JMIplus()), [-1, ])
+        index = np.reshape(np.array(a.JMIplus(dir_path)), [-1, ])
 
         self._index = (index - 1).astype(int)
         self._fitted = True
@@ -202,9 +207,9 @@ class JMIplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
 
 class STMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hyperparams]):
 
-    metadata = metadata_module.PrimitiveMetadata({
+    metadata = metadata_base.PrimitiveMetadata({
         'id': '9d1a2e58-5f97-386c-babd-5a9b4e9b6d6c',
-        'version': '2.1.2',
+        'version': '2.1.3',
         'name': 'STMBplus feature selector',
         'keywords': ['rpi primitives'],
         'source': {
@@ -212,14 +217,14 @@ class STMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
         },
         'installation':[
             {
-                'type': 'PIP',
+                'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.0.5'
+                'version': '2.0.7'
             },
             {
-                'type': 'PIP',
+                'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.1.7'
+	            'version': '2.1.8'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.STMBplus_Selector',
@@ -232,7 +237,7 @@ class STMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
     })
 
 
-    def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: typing.Dict[str, str] = None) -> None:
+    def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: typing.Union[typing.Dict[str, base.DockerContainer]] = None) -> None:
         super().__init__(hyperparams=hyperparams, random_seed=random_seed, docker_containers=docker_containers)
         self._index = None
         self._training_inputs = None
@@ -251,11 +256,12 @@ class STMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
 
         if self._training_inputs.any() == None or self._training_outputs.any() == None: 
             raise ValueError('Missing training data, or missing values exist.')
-
+        
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
+        dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))        
 
         a = rpi_feature_selection_toolbox.initialize()
-        index = np.reshape(np.array(a.STMBplus()), [-1, ])
+        index = np.reshape(np.array(a.STMBplus(dir_path)), [-1, ])
 
         self._index = (index - 1).astype(int)
         self._fitted = True
@@ -283,9 +289,9 @@ class STMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
 
 class aSTMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hyperparams]):
 
-    metadata = metadata_module.PrimitiveMetadata({
+    metadata = metadata_base.PrimitiveMetadata({
         'id': '744687e8-2224-3ef5-92e5-ce66d2ad05d7',
-        'version': '2.1.2',
+        'version': '2.1.3',
         'name': 'aSTMBplus feature selector',
         'keywords': ['rpi primitives'],
         'source': {
@@ -293,14 +299,14 @@ class aSTMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
         },
         'installation':[
             {
-                'type': 'PIP',
+                'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.0.5'
+                'version': '2.0.7'
             },
             {
-                'type': 'PIP',
+                'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.1.7'
+	            'version': '2.1.8'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.aSTMBplus_Selector',
@@ -313,7 +319,7 @@ class aSTMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
     })
 
 
-    def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: typing.Dict[str, str] = None) -> None:
+    def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: typing.Union[typing.Dict[str, base.DockerContainer]] = None) -> None:
         super().__init__(hyperparams=hyperparams, random_seed=random_seed, docker_containers=docker_containers)
         self._index = None
         self._training_inputs = None
@@ -334,9 +340,10 @@ class aSTMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
             raise ValueError('Missing training data, or missing values exist.')
 
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
+        dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
 
         a = rpi_feature_selection_toolbox.initialize()
-        index = np.reshape(np.array(a.aSTMBplus()), [-1, ])
+        index = np.reshape(np.array(a.aSTMBplus(dir_path)), [-1, ])
 
         self._index = (index - 1).astype(int)
         self._fitted = True
@@ -364,9 +371,9 @@ class aSTMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
 
 class sSTMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hyperparams]):
 
-    metadata = metadata_module.PrimitiveMetadata({
+    metadata = metadata_base.PrimitiveMetadata({
         'id': '976060b2-fb0a-329a-8851-d22b25ebe99a',
-        'version': '2.1.2',
+        'version': '2.1.3',
         'name': 'sSTMBplus feature selector',
         'keywords': ['rpi primitives'],
         'source': {
@@ -374,14 +381,14 @@ class sSTMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
         },
         'installation':[
             {
-                'type': 'PIP',
+                'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.0.5'
+                'version': '2.0.7'
             },
             {
-                'type': 'PIP',
+                'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.1.7'
+	            'version': '2.1.8'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.sSTMBplus_Selector',
@@ -394,7 +401,7 @@ class sSTMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
     })
 
 
-    def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: typing.Dict[str, str] = None) -> None:
+    def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: typing.Union[typing.Dict[str, base.DockerContainer]] = None) -> None:
         super().__init__(hyperparams=hyperparams, random_seed=random_seed, docker_containers=docker_containers)
         self._index = None
         self._training_inputs = None
@@ -415,9 +422,10 @@ class sSTMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
             raise ValueError('Missing training data, or missing values exist.')
 
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
+        dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
 
         a = rpi_feature_selection_toolbox.initialize()
-        index = np.reshape(np.array(a.sSTMBplus()), [-1, ])
+        index = np.reshape(np.array(a.sSTMBplus(dir_path)), [-1, ])
 
         self._index = (index - 1).astype(int)
         self._fitted = True
@@ -445,9 +453,9 @@ class sSTMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
 
 class pSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hyperparams]):
 
-    metadata = metadata_module.PrimitiveMetadata({
+    metadata = metadata_base.PrimitiveMetadata({
         'id': '616e087e-1bc8-3884-8675-3420bce832d5',
-        'version': '2.1.2',
+        'version': '2.1.3',
         'name': 'pSTMB feature selector',
         'keywords': ['rpi primitives'],
         'source': {
@@ -455,14 +463,14 @@ class pSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hyp
         },
         'installation':[
             {
-                'type': 'PIP',
+                'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.0.5'
+                'version': '2.0.7'
             },
             {
-                'type': 'PIP',
+                'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.1.7'
+	            'version': '2.1.8'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.pSTMB_Selector',
@@ -475,7 +483,7 @@ class pSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hyp
     })
 
 
-    def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: typing.Dict[str, str] = None) -> None:
+    def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: typing.Union[typing.Dict[str, base.DockerContainer]] = None) -> None:
         super().__init__(hyperparams=hyperparams, random_seed=random_seed, docker_containers=docker_containers)
         self._index = None
         self._training_inputs = None
@@ -496,9 +504,10 @@ class pSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hyp
             raise ValueError('Missing training data, or missing values exist.')
 
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
+        dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
 
         a = rpi_feature_selection_toolbox.initialize()
-        index = np.reshape(np.array(a.pSTMB()), [-1, ])
+        index = np.reshape(np.array(a.pSTMB(dir_path)), [-1, ])
 
         self._index = (index - 1).astype(int)
         self._fitted = True
@@ -525,9 +534,9 @@ class pSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hyp
 
 class F_STMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hyperparams]):
 
-    metadata = metadata_module.PrimitiveMetadata({
+    metadata = metadata_base.PrimitiveMetadata({
         'id': '37079f49-54d5-3d47-a221-5664c546ff90',
-        'version': '2.1.2',
+        'version': '2.1.3',
         'name': 'F_STMB feature selector',
         'keywords': ['rpi primitives'],
         'source': {
@@ -535,14 +544,14 @@ class F_STMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hy
         },
         'installation':[
             {
-                'type': 'PIP',
+                'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.0.5'
+                'version': '2.0.7'
             },
             {
-                'type': 'PIP',
+                'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.1.7'
+	            'version': '2.1.8'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.F_STMB_Selector',
@@ -555,7 +564,7 @@ class F_STMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hy
     })
 
 
-    def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: typing.Dict[str, str] = None) -> None:
+    def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: typing.Union[typing.Dict[str, base.DockerContainer]] = None) -> None:
         super().__init__(hyperparams=hyperparams, random_seed=random_seed, docker_containers=docker_containers)
         self._index = None
         self._training_inputs = None
@@ -576,9 +585,10 @@ class F_STMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hy
             raise ValueError('Missing training data, or missing values exist.')
 
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
+        dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
 
         a = rpi_feature_selection_toolbox.initialize()
-        index = np.reshape(np.array(a.F_STMB()), [-1, ])
+        index = np.reshape(np.array(a.F_STMB(dir_path)), [-1, ])
 
         self._index = (index - 1).astype(int)
         self._fitted = True
@@ -607,9 +617,9 @@ class F_STMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hy
 
 class F_aSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hyperparams]):
 
-    metadata = metadata_module.PrimitiveMetadata({
+    metadata = metadata_base.PrimitiveMetadata({
         'id': 'e6217c3c-b2d2-3e6b-82e9-060ffd0b9faf',
-        'version': '2.1.2',
+        'version': '2.1.3',
         'name': 'F_aSTMB feature selector',
         'keywords': ['rpi primitives'],
         'source': {
@@ -617,14 +627,14 @@ class F_aSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
         },
         'installation':[
             {
-                'type': 'PIP',
+                'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.0.5'
+                'version': '2.0.7'
             },
             {
-                'type': 'PIP',
+                'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.1.7'
+	            'version': '2.1.8'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.F_aSTMB_Selector',
@@ -637,7 +647,7 @@ class F_aSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
     })
 
 
-    def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: typing.Dict[str, str] = None) -> None:
+    def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: typing.Union[typing.Dict[str, base.DockerContainer]] = None) -> None:
         super().__init__(hyperparams=hyperparams, random_seed=random_seed, docker_containers=docker_containers)
         self._index = None
         self._training_inputs = None
@@ -658,9 +668,10 @@ class F_aSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
             raise ValueError('Missing training data, or missing values exist.')
 
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
+        dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
 
         a = rpi_feature_selection_toolbox.initialize()
-        index = np.reshape(np.array(a.F_aSTMB()), [-1, ])
+        index = np.reshape(np.array(a.F_aSTMB(dir_path)), [-1, ])
 
         self._index = (index - 1).astype(int)
         self._fitted = True
@@ -688,9 +699,9 @@ class F_aSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
 
 class F_sSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hyperparams]):
 
-    metadata = metadata_module.PrimitiveMetadata({
+    metadata = metadata_base.PrimitiveMetadata({
         'id': '6285b9fb-26e9-3979-a422-c126ff9448d1',
-        'version': '2.1.2',
+        'version': '2.1.3',
         'name': 'F_sSTMB feature selector',
         'keywords': ['rpi primitives'],
         'source': {
@@ -698,14 +709,14 @@ class F_sSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
         },
         'installation':[
             {
-                'type': 'PIP',
+                'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.0.5'
+                'version': '2.0.7'
             },
             {
-                'type': 'PIP',
+                'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.1.7'
+	            'version': '2.1.8'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.F_sSTMB_Selector',
@@ -718,7 +729,7 @@ class F_sSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
     })
 
 
-    def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: typing.Dict[str, str] = None) -> None:
+    def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: typing.Union[typing.Dict[str, base.DockerContainer]] = None) -> None:
         super().__init__(hyperparams=hyperparams, random_seed=random_seed, docker_containers=docker_containers)
         self._index = None
         self._training_inputs = None
@@ -739,9 +750,10 @@ class F_sSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
             raise ValueError('Missing training data, or missing values exist.')
 
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
+        dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
 
         a = rpi_feature_selection_toolbox.initialize()
-        index = np.reshape(np.array(a.F_sSTMB()), [-1, ])
+        index = np.reshape(np.array(a.F_sSTMB(dir_path)), [-1, ])
 
         self._index = (index - 1).astype(int)
         self._fitted = True
@@ -769,9 +781,9 @@ class F_sSTMB_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, H
 
 class JMIp_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hyperparams]):
 
-    metadata = metadata_module.PrimitiveMetadata({
+    metadata = metadata_base.PrimitiveMetadata({
         'id': 'd332d583-562f-374b-9737-d5d9c2208358',
-        'version': '2.1.2',
+        'version': '2.1.3',
         'name': 'JMIp feature selector',
         'keywords': ['rpi primitives'],
         'source': {
@@ -779,14 +791,14 @@ class JMIp_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hype
         },
         'installation':[
             {
-                'type': 'PIP',
+                'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_feature_selection_toolbox',
-                'version': '2.0.5'
+                'version': '2.0.7'
             },
             {
-                'type': 'PIP',
+                'type': metadata_base.PrimitiveInstallationType.PIP,
                 'package': 'rpi_featureSelection_python_tools',
-	            'version': '2.1.7'
+	            'version': '2.1.8'
             }
         ],
         'python_path': 'd3m.primitives.rpi_featureSelection_python_tools.JMIp_Selector',
@@ -799,7 +811,7 @@ class JMIp_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hype
     })
 
 
-    def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: typing.Dict[str, str] = None) -> None:
+    def __init__(self, *, hyperparams: Hyperparams, random_seed: int = 0, docker_containers: typing.Union[typing.Dict[str, base.DockerContainer]] = None) -> None:
         super().__init__(hyperparams=hyperparams, random_seed=random_seed, docker_containers=docker_containers)
         self._index = None
         self._training_inputs = None
@@ -820,9 +832,10 @@ class JMIp_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params, Hype
             raise ValueError('Missing training data, or missing values exist.')
 
         scipy.io.savemat('rpi_data.mat', mdict={'traindata': self._training_inputs, 'trainlabel': self._training_outputs})
+        dir_path = os.path.dirname(os.path.realpath('rpi_data.mat'))
 
         a = rpi_feature_selection_toolbox.initialize()
-        index = np.reshape(np.array(a.JMIp()), [-1, ])
+        index = np.reshape(np.array(a.JMIp(dir_path)), [-1, ])
 
         self._index = (index - 1).astype(int)
         self._fitted = True
